import { F as Fn } from './dom-42b5cffd.js';
import 'vue';

/**
 * Call onMounted() if it's inside a component lifecycle, if not, just call the function
 * This is useful when you want to call a function onMounted() but you don't know if it's
 * inside a component lifecycle or not
 *
 * Adapted from @vueuse/shared
 *
 * @param fn
 * @param sync if set to false, it will run in the nextTick() of Vue
 */
declare function tryOnMounted(fn: Fn, sync?: boolean): void;
/**
 * Call onBeforeMount() if it's inside a component lifecycle, if not, just call the function
 *
 * @param fn
 * @param sync if set to false, it will run in the nextTick() of Vue
 */
declare function tryOnBeforeMount(fn: Fn, sync?: boolean): void;
/**
 * Call onBeforeUnmount() if it's inside a component lifecycle, if not, do nothing
 *
 * @param fn
 */
declare function tryOnBeforeUnmount(fn: Fn): void;
/**
 * Call onUnmounted() if it's inside a component lifecycle, if not, do nothing
 *
 * @param fn
 */
declare function tryOnUnmounted(fn: Fn): void;

export { tryOnBeforeMount, tryOnBeforeUnmount, tryOnMounted, tryOnUnmounted };
